# Estatistica no R - Aula 3 (conteudo extra - Regressao)
# Luis Anunciacao (Psicometria, PUC-Rio/University of Oregon)
# luisfca@gmail.com www.anovabr.com

library(tidyverse)
set.seed(123)
#criar base
dist <- data.frame(depressao=rnorm(1000,43,2), idade=rnorm(1000,20,10))
dist <- dist %>% mutate(depressao = if_else(idade > mean(idade), 
                                           rnorm(1000,44.5,2),depressao))
dist %>% 
  summarise_at(vars(depressao,idade), funs(mean, sd)) %>% kable()

mod1 <- lm(depressao ~ idade, data=dist)
summary(mod1)

g <- ggplot(dist, aes(x=idade, y=depressao)) + geom_point()
g
g + geom_smooth(method = "lm")
g + geom_smooth(method = "lm") + geom_vline(xintercept = 0, linetype="dashed", color = "green", size=2) + geom_hline(yintercept = 42.53, linetype="dashed", color = "green", size=2)
g + geom_smooth(method = "lm") + geom_vline(xintercept = 0, linetype="dashed", color = "green", size=2) + geom_hline(yintercept = 42.53, linetype="dashed", color = "green", size=2) + geom_vline(xintercept = mean(dist$idade), linetype="dashed", color = "red", size=2) + geom_hline(yintercept = mean(dist$depressao), linetype="dashed", color = "red", size=2)
  
#adicionar mulheres  base
dist <- dist %>% mutate(mulheres = if_else(depressao > mean(depressao), 
                                            "1","0"))
mod2 <- lm(depressao ~ mulheres, data=dist)
summary(mod2)
t.test(depressao ~ mulheres, data=dist)

h <- ggplot(dist, aes(x=mulheres, y=depressao)) + geom_boxplot()
h
h + geom_smooth(method = "lm", se=TRUE, aes(group=1))

#modelo com idade e mulheres
mod3 <- lm(depressao ~ idade + mulheres, data=dist)
summary(mod3)

#plotar

i <- ggplot(dist, aes(x = idade, y = depressao, fill = mulheres)) +
  geom_point(size = 2, shape = 21) + geom_smooth(method="lm") 
i + facet_wrap(~mulheres, scales="free_x")  
i 

#predict
predict(mod3, data.frame(idade=c(0), mulheres=c("0"))) #intercepto
predict(mod3, data.frame(idade=20.03662, mulheres=c("1")))-predict(mod3, data.frame(idade=21.03662, mulheres=c("1")))


predict(mod3, data.frame(idade=mean(dist$idade), mulheres=c("1")))-predict(mod3, data.frame(idade=mean(dist$idade), mulheres=c("0")))

predict(mod3, data.frame(idade=20.03662, mulheres=c("0")))-
  predict(mod3, data.frame(idade=21.03662, mulheres=c("0"))) #incremento na idade, controlando para sexo

#plots alternativos
ggplot(dist, aes(x=idade, y=depressao)) + geom_point() + geom_boxplot(aes(x=mulheres, y=depressao)) + scale_x_discrete() #pontos e boxplot

ggplot(dist, aes(x=mulheres, y=depressao))+
  geom_boxplot() + geom_jitter(alpha=.2, aes(color=mulheres)) + stat_summary(fun.y=mean, geom="line", group=1)
  

# Luis Anunciacao, 2017
# This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. 
#https://creativecommons.org/licenses/by-nc-sa/4.0/